@@ -148,7 +148,7 @@ def cmd_install_sssp(version, functional, protocol, traceback):
 
 
 @cmd_install.command('pseudo-dojo')
-@options.VERSION(type=click.Choice(['0.3', '0.4', '1.0']), default='0.4', show_default=True)
+@options.VERSION(type=click.Choice(['0.4', '1.0']), default='0.4', show_default=True)
 @options.FUNCTIONAL(type=click.Choice(['PBE', 'PBEsol', 'LDA']), default='PBE', show_default=True)
 @options.RELATIVISTIC(type=click.Choice(['SR', 'SR3plus', 'FR']), default='SR', show_default=True)
 @options.PROTOCOL(type=click.Choice(['standard', 'stringent']), default='standard', show_default=True)
@@ -180,6 +180,15 @@ def cmd_install_pseudo_dojo(version, functional, relativistic, protocol, pseudo_
         'upf': UpfData,
     }
 
+    # yapf: disable
+    paw_configurations = (
+        PseudoDojoConfiguration('1.0', 'PBE', 'SR', 'standard', 'jthxml'),
+        PseudoDojoConfiguration('1.0', 'PBE', 'SR', 'stringent', 'jthxml'),
+        PseudoDojoConfiguration('1.0', 'LDA', 'SR', 'standard', 'jthxml'),
+        PseudoDojoConfiguration('1.0', 'LDA', 'SR', 'stringent', 'jthxml')
+    )
+    # yapf: enable
+
     try:
         pseudo_type = pseudo_type_mapping[pseudo_format]
     except KeyError:
@@ -231,6 +240,29 @@ def cmd_install_pseudo_dojo(version, functional, relativistic, protocol, pseudo_
                 msg = f'md5 of pseudo for element {element} does not match that of the metadata {md5}'
                 echo.echo_critical(msg)
 
+        # The PAW configurations have missing cutoffs for the Lanthanides, which have ben replaced with a placeholder
+        # value of `-1`. We replace these with the 1.5 * the maximum cutoff from the same stringency so that these
+        # potentials are still usable, but this should be taken as a _rough_ approximation.
+        # We check only the `cutoff_wfc` because `cutoff_rho` is not provided by PseudoDojo and is therefore
+        # locally calculated in `PseudoDojoFamily.parse_djrepos_from_archive` as `2.0 * cutoff_wfc` for PAW.
+        if configuration in paw_configurations:
+            adjusted_cutoffs = {}
+            for stringency, str_cutoffs in cutoffs.items():
+                adjusted_cutoffs[stringency] = []
+                max_cutoff_wfc = max([str_cutoffs[element]['cutoff_wfc'] for element in str_cutoffs])
+                filler_cutoff_wfc = max_cutoff_wfc * 1.5
+                for element, cutoff in str_cutoffs.items():
+                    if cutoff['cutoff_wfc'] <= 0:
+                        cutoffs[stringency][element]['cutoff_wfc'] = filler_cutoff_wfc
+                        cutoffs[stringency][element]['cutoff_rho'] = 2.0 * filler_cutoff_wfc
+                        adjusted_cutoffs[stringency].append(element)
+
+            for stringency, elements in adjusted_cutoffs.items():
+                msg = f'stringency `{stringency}` has missing recommended cutoffs for elements ' \
+                    f'{", ".join(elements)}: as a substitute, 1.5 * the maximum cutoff of the stringency ' \
+                    'was set for these elements. USE WITH CAUTION!'
+                echo.echo_warning(msg)
+
         family.description = description
         family.set_cutoffs(cutoffs, default_stringency=default_stringency)
 
